#
# spec file for package nss_wrapper
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################

Name:           nss_wrapper
Version:        1.1.3
Release:        lp152.3.4

Summary:        A wrapper for the user, group and hosts NSS API
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://cwrap.org/

Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc

BuildRequires:  cmake
BuildRequires:  libcmocka-devel
BuildRequires:  netcfg

Requires:       cmake
Requires:       pkg-config

%description
There are projects which provide daemons that need to be able to create, modify
and delete Unix users, or just switch user IDs to interact with the system, e.g.
a user space file server. To be able to test that, you need the privilege to
modify the passwd and groups files. With nss_wrapper, it is possible to define
your own passwd and groups files which will be used by software to act correctly
while under test.

If you have a client and server under test, they normally use functions to
resolve network names to addresses (DNS) or vice versa. The nss_wrappers allow
you to create a hosts file to setup name resolution for the addresses you use
with socket_wrapper.

To use it, set the following environment variables:

LD_PRELOAD=libuid_wrapper.so
NSS_WRAPPER_PASSWD=/path/to/passwd
NSS_WRAPPER_GROUP=/path/to/group
NSS_WRAPPER_HOSTS=/path/to/host

This package does not have a devel package, because this project is for
development/testing.

%prep
%setup -q

%build
%cmake \
  -DUNIT_TESTING=ON

make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

%check
pushd build
make %{?_smp_mflags} test || cat $(find Testing -name "*.log")
popd

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README ChangeLog COPYING
%{_bindir}/nss_wrapper.pl
%{_libdir}/libnss_wrapper.so*
%dir %{_libdir}/cmake/nss_wrapper
%{_libdir}/cmake/nss_wrapper/nss_wrapper-config-version.cmake
%{_libdir}/cmake/nss_wrapper/nss_wrapper-config.cmake
%dir %{_libdir}/pkgconfig
%{_libdir}/pkgconfig/nss_wrapper.pc
%{_mandir}/man1/nss_wrapper.1*

%changelog
* Mon Mar 21 2016 asn@cryptomilk.org
- Update to version 1.1.3
  * Added support for BSD 'struct passwd' members
  * Replaced strcpy() with snprintf()
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the description
- Use %%_smp_mflags for parallel build instead
* Thu Jan 14 2016 asn@cryptomilk.org
- Update to version 1.1.2
  * Fixed segfault while reloading hosts file
  * Fixed issue where are not fault tolerant if an alias has already
    been added
  * Fixed nss_wrapper build on Solaris
* Fri Nov 20 2015 asn@cryptomilk.org
- Update to version 1.1.0
  * Added support for initgroups()
  * Added support for shadow files (getspnam(), etc.)
  * Improved support for multi address handling in getaddrinfo()
  * Improved file parser
  * Fixed compilation on machines without IPv4 support
  * Fixed service string sanity check in getaddrinfo() (bso #11501)
  * Fixed AI_NUMERICHOST handling in getaddrinfo() (bso # 11477)
* Wed Jun  3 2015 mpluskal@suse.com
- Rename rpmlintrc to match packaging guidelines
- Add rpmlintrc as source
* Mon May 11 2015 asn@cryptomilk.org
- Cleanup specfile
* Thu Sep 11 2014 asn@cryptomilk.org
- Update to version 1.0.3.
  * Added a nss_wrapper manpage.
  * Fixed cmake find_package configs.
  * Fixed resolving hostnames with a trailing dot.
  * Fixed an overflow when checking if a IPv6 address is IPv4.
  * Fall back to RTLD_NEXT for symbol binding if we can't find libc.
* Thu Feb 13 2014 asn@cryptomilk.org
- Initial package.
